searchData={"items":[{"type":"module","title":"Expo.MO","doc":"File handling for MO (`.mo`) files.","ref":"Expo.MO.html"},{"type":"function","title":"Expo.MO.compose/2","doc":"Composes a MO (`.mo`) file from the given `messages`.\n\n#","ref":"Expo.MO.html#compose/2"},{"type":"function","title":"Examples - Expo.MO.compose/2","doc":"iex> %Expo.Messages{\n    ...>   headers: [\"Last-Translator: Jane Doe\"],\n    ...>   messages: [\n    ...>     %Expo.Message.Singular{msgid: [\"foo\"], msgstr: [\"bar\"], comments: \"A comment\"}\n    ...>   ]\n    ...> }\n    ...> |> Expo.MO.compose()\n    ...> |> IO.iodata_to_binary()\n     >","ref":"Expo.MO.html#compose/2-examples"},{"type":"function","title":"Expo.MO.parse_binary/2","doc":"Parses the given `binary` as an MO file.\n\nIf successful, returns `{:ok, messages}` where `messages` is a\n`Expo.Messages` struct. If there's an error, `{:error, error}` is returned\nwhere `error` is an exception struct.\n\n#","ref":"Expo.MO.html#parse_binary/2"},{"type":"function","title":"Examples - Expo.MO.parse_binary/2","doc":"iex> Expo.MO.parse_binary(    0xDE120495::size(4)-unit(8),\n    ...>   0::little-unsigned-integer-size(2)-unit(8),\n    ...>   0::little-unsigned-integer-size(2)-unit(8),\n    ...>   0::little-unsigned-integer-size(4)-unit(8),\n    ...>   28::little-unsigned-integer-size(4)-unit(8),\n    ...>   28::little-unsigned-integer-size(4)-unit(8),\n    ...>   28::little-unsigned-integer-size(4)-unit(8),\n    ...>   0::little-unsigned-integer-size(4)-unit(8)\n    ...> >>)\n    {:ok, %Expo.Messages{headers: [], messages: []}}","ref":"Expo.MO.html#parse_binary/2-examples"},{"type":"function","title":"Expo.MO.parse_binary!/2","doc":"Parses a string into a `Expo.Messages` struct, raising an exception if there are\nany errors.\n\nWorks exactly like `parse_binary/1`, but returns a `Expo.Messages` struct\nif there are no errors or raises an exception if there are.","ref":"Expo.MO.html#parse_binary!/2"},{"type":"function","title":"Examples - Expo.MO.parse_binary!/2","doc":"iex> Expo.MO.parse_binary!(    0xDE120495::size(4)-unit(8),\n    ...>   0::little-unsigned-integer-size(2)-unit(8),\n    ...>   0::little-unsigned-integer-size(2)-unit(8),\n    ...>   0::little-unsigned-integer-size(4)-unit(8),\n    ...>   28::little-unsigned-integer-size(4)-unit(8),\n    ...>   28::little-unsigned-integer-size(4)-unit(8),\n    ...>   28::little-unsigned-integer-size(4)-unit(8),\n    ...>   0::little-unsigned-integer-size(4)-unit(8)\n    ...> >>)\n    %Expo.Messages{headers: [], messages: []}\n\n    iex> Expo.MO.parse_binary!(\"invalid\")\n    ** (Expo.MO.InvalidFileError) invalid file","ref":"Expo.MO.html#parse_binary!/2-examples"},{"type":"function","title":"Expo.MO.parse_file/2","doc":"Parses the contents of the given file into a `Expo.Messages` struct.\n\nThis function works similarly to `parse_binary/1` except that it takes a file\nand parses the contents of that file as an MO file. It can return:\n\n  * `{:ok, po}` if the parsing is successful\n\n  * `{:error, line, reason}` if there is an error with the contents of the\n    `.mo` file (for example, a syntax error)\n\n  * `{:error, reason}` if there is an error with reading the file (this error\n    is one of the errors that can be returned by `File.read/1`)","ref":"Expo.MO.html#parse_file/2"},{"type":"function","title":"Examples - Expo.MO.parse_file/2","doc":"{:ok, po} = Expo.MO.parse_file(\"messages.po\")\n    po.file\n    #=> \"messages.po\"\n\n    Expo.MO.parse_file(\"nonexistent\")\n    #=> {:error, :enoent}","ref":"Expo.MO.html#parse_file/2-examples"},{"type":"function","title":"Expo.MO.parse_file!/2","doc":"Parses the contents of a file into a `Expo.Messages` struct, raising if there\nare any errors.\n\nWorks like `parse_file/1`, except that it raises an\nexception if there's an error with parsing the file or a `File.Error` error if\nthere's an error with reading the file.","ref":"Expo.MO.html#parse_file!/2"},{"type":"function","title":"Examples - Expo.MO.parse_file!/2","doc":"Expo.MO.parse_file!(\"nonexistent.po\")\n    #=> ** (File.Error) could not parse \"nonexistent.po\": no such file or directory","ref":"Expo.MO.html#parse_file!/2-examples"},{"type":"type","title":"Expo.MO.compose_option/0","doc":"","ref":"Expo.MO.html#t:compose_option/0"},{"type":"type","title":"Expo.MO.parse_option/0","doc":"","ref":"Expo.MO.html#t:parse_option/0"},{"type":"module","title":"Expo.Message","doc":"Functions to work on message structs (`Expo.Message.Singular` and `Expo.Message.Plural`).\n\nA message is a single PO singular or plural message. For example:\n\n    msgid \"Hello\"\n    msgstr \"\"\n\nMessage structs are used both to represent reference messages (where the `msgstr` is empty)\nin POT files as well as actual translations.","ref":"Expo.Message.html"},{"type":"function","title":"Expo.Message.append_flag/2","doc":"Appends the given `flag` to the given `message`.\n\nKeeps the line formatting intact.\n\n#","ref":"Expo.Message.html#append_flag/2"},{"type":"function","title":"Examples - Expo.Message.append_flag/2","doc":"iex> message = %Expo.Message.Singular{msgid: [], flags: []}\n    iex> Expo.Message.append_flag(message, \"foo\")\n    %Expo.Message.Singular{msgid: [], flags: [[\"foo\"]]}","ref":"Expo.Message.html#append_flag/2-examples"},{"type":"function","title":"Expo.Message.has_flag?/2","doc":"Tells whether the given `message` has the given `flag` specified.\n\n#","ref":"Expo.Message.html#has_flag?/2"},{"type":"function","title":"Examples - Expo.Message.has_flag?/2","doc":"iex> Expo.Message.has_flag?(%Expo.Message.Singular{msgid: [], flags: [[\"foo\"]]}, \"foo\")\n    true\n\n    iex> Expo.Message.has_flag?(%Expo.Message.Singular{msgid: [], flags: [[\"foo\"]]}, \"bar\")\n    false","ref":"Expo.Message.html#has_flag?/2-examples"},{"type":"function","title":"Expo.Message.key/1","doc":"Returns a \"key\" that can be used to identify a message.\n\nThis function returns a \"key\" that can be used to uniquely identify a\nmessage assuming that no \"same\" messages exist; for what \"same\"\nmeans, look at the documentation for `same?/2`.\n\nThe purpose of this function is to be used in situations where we'd like to\ngroup or sort messages but where we don't need the whole structs.","ref":"Expo.Message.html#key/1"},{"type":"function","title":"Examples - Expo.Message.key/1","doc":"iex> t1 = %Expo.Message.Singular{msgid: [\"foo\"]}\n    iex> t2 = %Expo.Message.Singular{msgid: [\"\", \"foo\"]}\n    iex> Expo.Message.key(t1) == Expo.Message.key(t2)\n    true\n\n    iex> t1 = %Expo.Message.Singular{msgid: [\"foo\"]}\n    iex> t2 = %Expo.Message.Singular{msgid: [\"bar\"]}\n    iex> Expo.Message.key(t1) == Expo.Message.key(t2)\n    false","ref":"Expo.Message.html#key/1-examples"},{"type":"function","title":"Expo.Message.merge/2","doc":"Merges two messages.\n\nIf both messages are `Expo.Message.Singular`, the result is a singular message.\nIf one of the two messages is a `Expo.Message.Plural`, the result is a plural message.\nThis is consistent with the behavior of GNU Gettext.","ref":"Expo.Message.html#merge/2"},{"type":"function","title":"Examples - Expo.Message.merge/2","doc":"iex> msg1 = %Expo.Message.Singular{msgid: [\"test\"], flags: [[\"one\"]]}\n    ...> msg2 = %Expo.Message.Singular{msgid: [\"test\"], flags: [[\"one\", \"two\"]]}\n    ...> Expo.Message.merge(msg1, msg2)\n    %Expo.Message.Singular{msgid: [\"test\"], flags: [[\"one\", \"two\"]]}\n\n    iex> msg1 = %Expo.Message.Singular{msgid: [\"test\"]}\n    ...> msg2 = %Expo.Message.Plural{msgid: [\"test\"], msgid_plural: [\"tests\"]}\n    ...> Expo.Message.merge(msg1, msg2)\n    %Expo.Message.Plural{msgid: [\"test\"], msgid_plural: [\"tests\"]}","ref":"Expo.Message.html#merge/2-examples"},{"type":"function","title":"Expo.Message.same?/2","doc":"Tells whether two messages are the same message according to their\n`msgid`.\n\nThis function returns `true` if `message1` and `message2` are the same\nmessage, where \"the same\" means they have the same `msgid` or the same\n`msgid` and `msgid_plural`.","ref":"Expo.Message.html#same?/2"},{"type":"function","title":"Examples - Expo.Message.same?/2","doc":"iex> t1 = %Expo.Message.Singular{msgid: [\"foo\"]}\n    iex> t2 = %Expo.Message.Singular{msgid: [\"\", \"foo\"]}\n    iex> Expo.Message.same?(t1, t2)\n    true\n\n    iex> t1 = %Expo.Message.Singular{msgid: [\"foo\"]}\n    iex> t2 = %Expo.Message.Singular{msgid: [\"bar\"]}\n    iex> Expo.Message.same?(t1, t2)\n    false","ref":"Expo.Message.html#same?/2-examples"},{"type":"function","title":"Expo.Message.source_line_number/3","doc":"Get the source line number of the message.","ref":"Expo.Message.html#source_line_number/3"},{"type":"function","title":"Examples - Expo.Message.source_line_number/3","doc":"iex> %Expo.Messages{messages: [message]} = Expo.PO.parse_string!(\"\"\"\n    ...> msgid \"foo\"\n    ...> msgstr \"bar\"\n    ...> \"\"\")\n    iex> Expo.Message.source_line_number(message, :msgid)\n    1","ref":"Expo.Message.html#source_line_number/3-examples"},{"type":"opaque","title":"Expo.Message.key/0","doc":"The key that can be used to identify a message.\n\nSee `key/1`.","ref":"Expo.Message.html#t:key/0"},{"type":"type","title":"Expo.Message.msgctxt/0","doc":"The `msgctxt` of a message.","ref":"Expo.Message.html#t:msgctxt/0"},{"type":"type","title":"Expo.Message.msgid/0","doc":"The `msgid` of a message.","ref":"Expo.Message.html#t:msgid/0"},{"type":"type","title":"Expo.Message.msgstr/0","doc":"The `msgstr` of a message.","ref":"Expo.Message.html#t:msgstr/0"},{"type":"type","title":"Expo.Message.split_string/0","doc":"A list of strings representing *lines*.\n\nThis type is used for types such as `t:msgid/0`. The list of strings\nrepresents the message split into multiple lines, as parsed from a PO(T) file.","ref":"Expo.Message.html#t:split_string/0"},{"type":"type","title":"Expo.Message.t/0","doc":"A type for either a singular or a plural message.","ref":"Expo.Message.html#t:t/0"},{"type":"module","title":"Expo.Message.Plural","doc":"Struct for plural messages.\n\nFor example:\n\n    msgid \"Cat\"\n    msgid_plural \"Cats\"\n    msgstr \"\"\n\nSee [`%Expo.Message.Plural{}`](`__struct__/0`) for documentation on the fields of this struct.","ref":"Expo.Message.Plural.html"},{"type":"function","title":"Expo.Message.Plural.__struct__/0","doc":"The struct for a plural message.\n\nAll fields in this struct are public except for `:__meta__`. The `:flags` and `:references`\nfields are defined as lists of lists in order to represent **lines** in the original file. For\nexample, this message:\n\n    #, flag1, flag2\n    #, flag3\n    #: a.ex:1\n    #: b.ex:2 c.ex:3\n    msgid \"Hello\"\n    msgstr \"\"\n\nwould have:\n\n  * `flags: [[\"flag1\", \"flag2\"], [\"flag3\"]]`\n  * `references: [[\"a.ex:1\"], [\"b.ex:2\", \"c.ex:3\"]]`\n\nYou can use `Expo.Message.has_flag?/2` to make it easier to check whether a message\nhas a given flag.","ref":"Expo.Message.Plural.html#__struct__/0"},{"type":"function","title":"Expo.Message.Plural.key/1","doc":"Returns the **key** of the message.\n\nThe key takes the msgctxt into consideration by returning a tuple `{msgctxt, msgid}`.\nBoth `msgctxt` and `msgid` are normalized to binaries (instead of keeping line information)\nfor easier comparison.","ref":"Expo.Message.Plural.html#key/1"},{"type":"function","title":"Examples - Expo.Message.Plural.key/1","doc":"iex> Plural.key(%Plural{msgid: [\"cat\"], msgid_plural: [\"cats\"]})\n    {\"\", \"cat\"}","ref":"Expo.Message.Plural.html#key/1-examples"},{"type":"function","title":"Expo.Message.Plural.merge/2","doc":"Merges two plural messages.","ref":"Expo.Message.Plural.html#merge/2"},{"type":"function","title":"Examples - Expo.Message.Plural.merge/2","doc":"iex> msg1 = %Expo.Message.Plural{msgid: [\"test\"], msgid_plural: [\"one\"], flags: [[\"one\"]], msgstr: %{0 => \"une\"}}\n    ...> msg2 = %Expo.Message.Plural{msgid: [\"test\"], msgid_plural: [\"two\"], flags: [[\"two\"]], msgstr: %{2 => \"deux\"}}\n    ...> Expo.Message.Plural.merge(msg1, msg2)\n    %Expo.Message.Plural{msgid: [\"test\"], msgid_plural: [\"two\"], flags: [[\"two\", \"one\"]], msgstr: %{0 => \"une\", 2 => \"deux\"}}","ref":"Expo.Message.Plural.html#merge/2-examples"},{"type":"function","title":"Expo.Message.Plural.rebalance/1","doc":"Re-balances all strings in the message.\n\nThis function does these things:\n\n  * Put one string per newline of `msgid`/`msgid_plural`/`msgstr`\n  * Put all flags onto one line\n  * Put all references onto a separate line\n\n#","ref":"Expo.Message.Plural.html#rebalance/1"},{"type":"function","title":"Examples - Expo.Message.Plural.rebalance/1","doc":"iex> Plural.rebalance(%Plural{\n    ...>   msgid: [\"\", \"hello\", \"\\n\", \"\", \"world\", \"\"],\n    ...>   msgid_plural: [\"\", \"hello\", \"\\n\", \"\", \"world\", \"\"],\n    ...>   msgstr: %{0 => [\"\", \"hello\", \"\\n\", \"\", \"world\", \"\"]},\n    ...>   flags: [[\"one\", \"two\"], [\"three\"]],\n    ...>   references: [[{\"one\", 1}, {\"two\", 2}], [\"three\"]]\n    ...> })\n    %Plural{\n      msgid: [\"hello\\n\", \"world\"],\n      msgid_plural: [\"hello\\n\", \"world\"],\n      msgstr: %{0 => [\"hello\\n\", \"world\"]},\n      flags: [[\"one\", \"two\", \"three\"]],\n      references: [[{\"one\", 1}], [{\"two\", 2}], [\"three\"]]\n    }","ref":"Expo.Message.Plural.html#rebalance/1-examples"},{"type":"function","title":"Expo.Message.Plural.source_line_number/3","doc":"Get the source line number of the message.","ref":"Expo.Message.Plural.html#source_line_number/3"},{"type":"function","title":"Examples - Expo.Message.Plural.source_line_number/3","doc":"iex> %Expo.Messages{messages: [message]} = Expo.PO.parse_string!(\"\"\"\n    ...> msgid \"foo\"\n    ...> msgid_plural \"foos\"\n    ...> msgstr[0] \"bar\"\n    ...> \"\"\")\n    iex> Plural.source_line_number(message, :msgid)\n    1\n    iex> Plural.source_line_number(message, {:msgstr, 0})\n    3","ref":"Expo.Message.Plural.html#source_line_number/3-examples"},{"type":"type","title":"Expo.Message.Plural.block/0","doc":"The \"component\" of a message.","ref":"Expo.Message.Plural.html#t:block/0"},{"type":"opaque","title":"Expo.Message.Plural.key/0","doc":"The key that identifies this message.","ref":"Expo.Message.Plural.html#t:key/0"},{"type":"opaque","title":"Expo.Message.Plural.meta/0","doc":"Metadata for this struct.","ref":"Expo.Message.Plural.html#t:meta/0"},{"type":"type","title":"Expo.Message.Plural.t/0","doc":"The type for this struct.\n\nSee [`%__MODULE__{}`](`__struct__/0`) for documentation on the fields of this struct.","ref":"Expo.Message.Plural.html#t:t/0"},{"type":"module","title":"Expo.Message.Singular","doc":"Struct for non-plural messages.\n\nFor example:\n\n    msgid \"Hello\"\n    msgstr \"\"\n\nSee [`%Expo.Message.Singular{}`](`__struct__/0`) for documentation on the fields of this struct.","ref":"Expo.Message.Singular.html"},{"type":"function","title":"Expo.Message.Singular.__struct__/0","doc":"The struct for a non-plural message.\n\nThe `:flags` and `:references` fields are defined as lists of lists in order to represent\n**lines** in the original file. For example, this message:\n\n    #, flag1, flag2\n    #, flag3\n    #: a.ex:1\n    #: b.ex:2 c.ex:3\n    msgid \"Hello\"\n    msgstr \"\"\n\nwould have:\n\n  * `flags: [[\"flag1\", \"flag2\"], [\"flag3\"]]`\n  * `references: [[\"a.ex:1\"], [\"b.ex:2\", \"c.ex:3\"]]`\n\nYou can use `Expo.Message.has_flag?/2` to make it easier to check whether a message has a given\nflag.","ref":"Expo.Message.Singular.html#__struct__/0"},{"type":"function","title":"Expo.Message.Singular.key/1","doc":"Returns the **key** of the message.\n\nThe key takes the msgctxt into consideration by returning a tuple `{msgctxt, msgid}`.\nBoth `msgctxt` and `msgid` are normalized to binaries (instead of keeping line information)\nfor easier comparison.","ref":"Expo.Message.Singular.html#key/1"},{"type":"function","title":"Examples - Expo.Message.Singular.key/1","doc":"iex> Singular.key(%Singular{msgid: [\"foo\"]})\n    {\"\", \"foo\"}\n\n    iex> Singular.key(%Singular{msgid: [\"foo\"], msgctxt: [\"con\", \"text\"]})\n    {\"context\", \"foo\"}","ref":"Expo.Message.Singular.html#key/1-examples"},{"type":"function","title":"Expo.Message.Singular.merge/2","doc":"Merges two singular messages.","ref":"Expo.Message.Singular.html#merge/2"},{"type":"function","title":"Examples - Expo.Message.Singular.merge/2","doc":"iex> msg1 = %Expo.Message.Singular{msgid: [\"test\"], flags: [[\"one\"]]}\n    ...> msg2 = %Expo.Message.Singular{msgid: [\"test\"], flags: [[\"two\"]]}\n    ...> Expo.Message.Singular.merge(msg1, msg2)\n    %Expo.Message.Singular{msgid: [\"test\"], flags: [[\"two\", \"one\"]]}","ref":"Expo.Message.Singular.html#merge/2-examples"},{"type":"function","title":"Expo.Message.Singular.rebalance/1","doc":"Re-balances all strings in the given message.\n\nThis function does these things:\n\n  * Puts one string per newline of `msgid`/`msgstr`\n  * Puts all flags onto one line\n  * Puts all references onto a separate line\n\n#","ref":"Expo.Message.Singular.html#rebalance/1"},{"type":"function","title":"Examples - Expo.Message.Singular.rebalance/1","doc":"iex> Singular.rebalance(%Singular{\n    ...>   msgid: [\"\", \"hello\", \"\\n\", \"\", \"world\", \"\"],\n    ...>   msgstr: [\"\", \"hello\", \"\\n\", \"\", \"world\", \"\"],\n    ...>   flags: [[\"one\", \"two\"], [\"three\"]],\n    ...>   references: [[{\"one\", 1}, {\"two\", 2}], [\"three\"]]\n    ...> })\n    %Singular{\n      msgid: [\"hello\\n\", \"world\"],\n      msgstr: [\"hello\\n\", \"world\"],\n      flags: [[\"one\", \"two\", \"three\"]],\n      references: [[{\"one\", 1}], [{\"two\", 2}], [\"three\"]]\n    }","ref":"Expo.Message.Singular.html#rebalance/1-examples"},{"type":"function","title":"Expo.Message.Singular.source_line_number/3","doc":"Gets the source line number of the message.","ref":"Expo.Message.Singular.html#source_line_number/3"},{"type":"function","title":"Examples - Expo.Message.Singular.source_line_number/3","doc":"iex> %Expo.Messages{messages: [message]} = Expo.PO.parse_string!(\"\"\"\n    ...> msgid \"foo\"\n    ...> msgstr \"bar\"\n    ...> \"\"\")\n    iex> Singular.source_line_number(message, :msgid)\n    1\n    iex> Singular.source_line_number(message, :msgstr)\n    2","ref":"Expo.Message.Singular.html#source_line_number/3-examples"},{"type":"type","title":"Expo.Message.Singular.block/0","doc":"The name of the \"component\" of a message.","ref":"Expo.Message.Singular.html#t:block/0"},{"type":"opaque","title":"Expo.Message.Singular.key/0","doc":"The key that identifies this message.","ref":"Expo.Message.Singular.html#t:key/0"},{"type":"opaque","title":"Expo.Message.Singular.meta/0","doc":"Metadata for this struct.","ref":"Expo.Message.Singular.html#t:meta/0"},{"type":"type","title":"Expo.Message.Singular.t/0","doc":"The type for this struct.\n\nSee [`%__MODULE__{}`](`__struct__/0`) for documentation on the fields of this struct.","ref":"Expo.Message.Singular.html#t:t/0"},{"type":"module","title":"Expo.Messages","doc":"A struct that represents lists of `Expo.Message.Singular` and `Expo.Message.Plural`\nstructs for MO and PO files.\n\nAll fields in the struct are public. See [`%Expo.Messages{}`](`__struct__/0`).","ref":"Expo.Messages.html"},{"type":"function","title":"Expo.Messages.__struct__/0","doc":"The struct to represent a list of messages.\n\nFor the type of each field, see `t:t/0`.","ref":"Expo.Messages.html#__struct__/0"},{"type":"function","title":"Expo.Messages.find/2","doc":"Finds a given `message_to_find` in a list of `messages`.\n\nEquality between messages is checked using `Expo.Message.same?/2`.\n\nReturns `nil` if `message_to_find` is not found.","ref":"Expo.Messages.html#find/2"},{"type":"function","title":"Expo.Messages.get_header/2","doc":"Gets a header by name.\n\nThe name of the header is case-insensitive.\n\n#","ref":"Expo.Messages.html#get_header/2"},{"type":"function","title":"Examples - Expo.Messages.get_header/2","doc":"iex> messages = %Expo.Messages{headers: [\"Language: en_US\\n\"], messages: []}\n    iex> Expo.Messages.get_header(messages, \"language\")\n    [\"en_US\"]\n\n    iex> messages = %Expo.Messages{headers: [\"Language: en_US\\n\"], messages: []}\n    iex> Expo.Messages.get_header(messages, \"invalid\")\n    []","ref":"Expo.Messages.html#get_header/2-examples"},{"type":"function","title":"Expo.Messages.rebalance/1","doc":"Re-balances all strings.\n\nThis function does the following things:\n\n  * Re-balances all headers (see `Expo.Message.Singular.rebalance/1` and\n    `Expo.Message.Plural.rebalance/1`)\n\n  * Puts one string per newline of `headers` and add one empty line at start\n\n#","ref":"Expo.Messages.html#rebalance/1"},{"type":"function","title":"Examples - Expo.Messages.rebalance/1","doc":"iex> Expo.Messages.rebalance(%Expo.Messages{\n    ...>   headers: [\"\", \"hello\", \"\\n\", \"\", \"world\", \"\"],\n    ...>   messages: [%Expo.Message.Singular{\n    ...>     msgid: [\"\", \"hello\", \"\\n\", \"\", \"world\", \"\"],\n    ...>     msgstr: [\"\", \"hello\", \"\\n\", \"\", \"world\", \"\"]\n    ...>   }]\n    ...> })\n    %Expo.Messages{\n      headers: [\"\", \"hello\\n\", \"world\"],\n      messages: [%Expo.Message.Singular{\n        msgid: [\"hello\\n\", \"world\"],\n        msgstr: [\"hello\\n\", \"world\"]\n      }]\n    }","ref":"Expo.Messages.html#rebalance/1-examples"},{"type":"type","title":"Expo.Messages.t/0","doc":"The type for this struct.","ref":"Expo.Messages.html#t:t/0"},{"type":"module","title":"Expo.PO","doc":"File handling for PO (`.po`) and POT (`.pot`) files.","ref":"Expo.PO.html"},{"type":"function","title":"Expo.PO.compose/1","doc":"Dumps a `Expo.Messages` struct as iodata.\n\nThis function dumps a `Expo.Messages` struct (representing a PO file) as iodata,\nwhich can later be written to a file or converted to a string with\n`IO.iodata_to_binary/1`.","ref":"Expo.PO.html#compose/1"},{"type":"function","title":"Examples - Expo.PO.compose/1","doc":"After running the following code:\n\n    iodata =\n      Expo.PO.compose(%Expo.Messages{\n        headers: [\"Last-Translator: Jane Doe\"],\n        messages: [\n          %Expo.Message.Singular{msgid: [\"foo\"], msgstr: [\"bar\"], comments: \"A comment\"}\n        ]\n      })\n\n    File.write!(\"/tmp/test.po\", iodata)\n\nthe `/tmp/test.po` file would look like this:\n\n    msgid \"\"\n    msgstr \"\"\n    \"Last-Translator: Jane Doe\"\n\n    # A comment\n    msgid \"foo\"\n    msgstr \"bar\"","ref":"Expo.PO.html#compose/1-examples"},{"type":"function","title":"Expo.PO.parse_file/2","doc":"Parses the contents of a file into a `Expo.Messages` struct.\n\nThis function works similarly to `parse_string/1` except that it takes a file\nand parses the contents of that file. It can return:\n\n  * `{:ok, po}` if the parsing is successful\n\n  * `{:error, error}` if there is an error with the contents of the\n    `.po` file (for example, a syntax error); `error` is an exception struct\n\n  * `{:error, reason}` if there is an error with reading the file (this error\n    is one of the errors that can be returned by `File.read/1`)","ref":"Expo.PO.html#parse_file/2"},{"type":"function","title":"Examples - Expo.PO.parse_file/2","doc":"{:ok, po} = Expo.PO.parse_file(\"messages.po\")\n    po.file\n    #=> \"messages.po\"\n\n    Expo.PO.parse_file(\"nonexistent\")\n    #=> {:error, :enoent}","ref":"Expo.PO.html#parse_file/2-examples"},{"type":"function","title":"Expo.PO.parse_file!/2","doc":"Parses the contents of a file into a `Expo.Messages` struct, raising if there\nare any errors.\n\nWorks like `parse_file/1`, except that it raises an exception\nif there are issues with the contents of the file or with reading the file.","ref":"Expo.PO.html#parse_file!/2"},{"type":"function","title":"Examples - Expo.PO.parse_file!/2","doc":"Expo.PO.parse_file!(\"nonexistent.po\")\n    #=> ** (File.Error) could not parse \"nonexistent.po\": no such file or directory","ref":"Expo.PO.html#parse_file!/2-examples"},{"type":"function","title":"Expo.PO.parse_string/2","doc":"Parses the given `string` into a `Expo.Messages` struct.\n\nIt returns `{:ok, messages}` if there are no errors, otherwise\n`{:error, error}` where `error` is an exception struct.","ref":"Expo.PO.html#parse_string/2"},{"type":"function","title":"Examples - Expo.PO.parse_string/2","doc":"iex> {:ok, po} = Expo.PO.parse_string(\"\"\"\n    ...> msgid \"foo\"\n    ...> msgstr \"bar\"\n    ...> \"\"\")\n    iex> [message] = po.messages\n    iex> message.msgid\n    [\"foo\"]\n    iex> message.msgstr\n    [\"bar\"]\n    iex> po.headers\n    []\n\n    iex> Expo.PO.parse_string(\"foo\")\n    {:error, %Expo.PO.SyntaxError{line: 1, reason: \"unknown keyword 'foo'\"}}","ref":"Expo.PO.html#parse_string/2-examples"},{"type":"function","title":"Expo.PO.parse_string!/2","doc":"Parses `string` into a `Expo.Messages` struct, raising an exception if there are\nany errors.\n\nWorks exactly like `parse_string/1`, but returns a `Expo.Messages` struct\nif there are no errors or raises an exception if there are.","ref":"Expo.PO.html#parse_string!/2"},{"type":"function","title":"Examples - Expo.PO.parse_string!/2","doc":"iex> po = Expo.PO.parse_string!(\"\"\"\n    ...> msgid \"foo\"\n    ...> msgstr \"bar\"\n    ...> \"\"\")\n    iex> [message] = po.messages\n    iex> message.msgid\n    [\"foo\"]\n    iex> message.msgstr\n    [\"bar\"]\n    iex> po.headers\n    []\n\n    iex> Expo.PO.parse_string!(\"msgid\")\n    ** (Expo.PO.SyntaxError) 1: no space after 'msgid'","ref":"Expo.PO.html#parse_string!/2-examples"},{"type":"type","title":"Expo.PO.parse_option/0","doc":"","ref":"Expo.PO.html#t:parse_option/0"},{"type":"module","title":"Expo.PluralForms","doc":"Functions to parse and evaluate plural forms as defined in the GNU Gettext documentation.\n\nThe documentation is available at\n .","ref":"Expo.PluralForms.html"},{"type":"module","title":"Usage - Expo.PluralForms","doc":"Some functions in this module are considered \"low level\", and are meant to be\nused by other libraries. For example, `parse/1` returns an expression\nthat is not really meant to be inspected, but rather used internally by this library.","ref":"Expo.PluralForms.html#module-usage"},{"type":"function","title":"Expo.PluralForms.index/2","doc":"Gets the plural form for the given number based on the given `plural_forms` struct.\n\n#","ref":"Expo.PluralForms.html#index/2"},{"type":"function","title":"Examples - Expo.PluralForms.index/2","doc":"iex> {:ok, plural_form} = Expo.PluralForms.parse(\"nplurals=2; plural=n != 1;\")\n    iex> Expo.PluralForms.index(plural_form, 4)\n    1\n    iex> Expo.PluralForms.index(plural_form, 1)\n    0","ref":"Expo.PluralForms.html#index/2-examples"},{"type":"function","title":"Expo.PluralForms.known_locales/0","doc":"Get known locales where plural form information is available.\n\n#","ref":"Expo.PluralForms.html#known_locales/0"},{"type":"function","title":"Examples - Expo.PluralForms.known_locales/0","doc":"iex> \"de\" in Expo.PluralForms.known_locales()\n    true\n\n    iex> \"invalid\" in Expo.PluralForms.known_locales()\n    false","ref":"Expo.PluralForms.html#known_locales/0-examples"},{"type":"function","title":"Expo.PluralForms.parse/1","doc":"Parses a plural forms string into a `t:t/0` struct.\n\nReturns `{:ok, struct}` if the string is valid, or `{:error, error}`\nif it isn't.\n\n#","ref":"Expo.PluralForms.html#parse/1"},{"type":"function","title":"Examples - Expo.PluralForms.parse/1","doc":"iex> Expo.PluralForms.parse(\"nplurals=2; plural=n != 1;\")\n    {:ok, Expo.PluralForms.parse!(\"nplurals=2; plural=n != 1;\")}","ref":"Expo.PluralForms.html#parse/1-examples"},{"type":"function","title":"Expo.PluralForms.parse!/1","doc":"Parses a plural forms string into a `t:t/0` struct, raising if there are errors.\n\nSame as `parse/1`, but returns the plural forms struct directly if the\nparsing is successful, or raises an error otherwise.\n\nThe `Inspect` implementation for the `Expo.PluralForms` struct uses this function\nto display the plural forms expression, which is why the example below might\nlook a bit weird.","ref":"Expo.PluralForms.html#parse!/1"},{"type":"function","title":"Examples - Expo.PluralForms.parse!/1","doc":"iex> Expo.PluralForms.parse!(\"nplurals=2; plural=n != 1;\")\n    Expo.PluralForms.parse!(\"nplurals=2; plural=n != 1;\")","ref":"Expo.PluralForms.html#parse!/1-examples"},{"type":"function","title":"Expo.PluralForms.plural_form/1","doc":"Gets the plural form for the given language based on built-in information.\n\n#","ref":"Expo.PluralForms.html#plural_form/1"},{"type":"function","title":"Examples - Expo.PluralForms.plural_form/1","doc":"iex> Expo.PluralForms.plural_form(\"de\")\n    {:ok, Expo.PluralForms.parse!(\"nplurals=2; plural=(n != 1);\")}\n\n    iex> Expo.PluralForms.plural_form(\"invalid\")\n    :error","ref":"Expo.PluralForms.html#plural_form/1-examples"},{"type":"function","title":"Expo.PluralForms.to_string/1","doc":"Converts a plural forms struct into its string representation.","ref":"Expo.PluralForms.html#to_string/1"},{"type":"function","title":"Examples - Expo.PluralForms.to_string/1","doc":"iex> plural_forms = Expo.PluralForms.parse!(\"nplurals=2; plural=n != 1;\")\n    iex> Expo.PluralForms.to_string(plural_forms)\n    \"nplurals=2; plural=n != 1;\"","ref":"Expo.PluralForms.html#to_string/1-examples"},{"type":"opaque","title":"Expo.PluralForms.plural_ast/0","doc":"The AST of a plural forms expression.\n\nThis is evaluated internally to determine the plural form for a given number\nusing `index/2`, and is not meant to be inspected directly.","ref":"Expo.PluralForms.html#t:plural_ast/0"},{"type":"type","title":"Expo.PluralForms.t/0","doc":"A struct representing a plural forms expression.","ref":"Expo.PluralForms.html#t:t/0"},{"type":"task","title":"mix expo.msgfmt","doc":"Generate binary message catalog from textual message description.\n\n    mix expo.msgfmt [PO_FILE] [OPTIONS]","ref":"Mix.Tasks.Expo.Msgfmt.html"},{"type":"task","title":"Options - mix expo.msgfmt","doc":"* `--use-fuzzy` - use fuzzy entries in output\n* `--endianness=BYTEORDER` - write out 32-bit numbers in the given byte\n  order (big or little, default depends on platform)\n* `--output-file=FILE` - write output to specified file\n* `--statistics` - print statistics about messages","ref":"Mix.Tasks.Expo.Msgfmt.html#module-options"},{"type":"task","title":"mix expo.msguniq","doc":"Unifies duplicate translations in the given PO file.\n\nBy default, this task outputs the file on standard output. If you want to\n*overwrite* the given PO file, pass in the `--output` flag.\n\n*This task is available since v0.5.0.*","ref":"Mix.Tasks.Expo.Msguniq.html"},{"type":"task","title":"Usage - mix expo.msguniq","doc":"mix expo.msguniq PO_FILE [--output-file=OUTPUT_FILE]","ref":"Mix.Tasks.Expo.Msguniq.html#module-usage"},{"type":"task","title":"Options - mix expo.msguniq","doc":"* `--output-file` (`-o`) - File to store the output in. `-` for\n  standard output. Defaults to `-`.","ref":"Mix.Tasks.Expo.Msguniq.html#module-options"},{"type":"exception","title":"Expo.MO.InvalidFileError","doc":"An error raised when the content does not follow the MO file structure.\n\nThe fields of this exception are public.","ref":"Expo.MO.InvalidFileError.html"},{"type":"type","title":"Expo.MO.InvalidFileError.t/0","doc":"","ref":"Expo.MO.InvalidFileError.html#t:t/0"},{"type":"exception","title":"Expo.MO.UnsupportedVersionError","doc":"An error returned when the version of the MO file is not supported.\n\nAll the fields in this struct are public.","ref":"Expo.MO.UnsupportedVersionError.html"},{"type":"type","title":"Expo.MO.UnsupportedVersionError.t/0","doc":"","ref":"Expo.MO.UnsupportedVersionError.html#t:t/0"},{"type":"exception","title":"Expo.PO.DuplicateMessagesError","doc":"An error raised when duplicate messages are detected.","ref":"Expo.PO.DuplicateMessagesError.html"},{"type":"type","title":"Expo.PO.DuplicateMessagesError.t/0","doc":"The type for this exception struct.","ref":"Expo.PO.DuplicateMessagesError.html#t:t/0"},{"type":"exception","title":"Expo.PO.SyntaxError","doc":"An error raised when the syntax in a PO file (a file ending in `.po`) isn't\ncorrect.","ref":"Expo.PO.SyntaxError.html"},{"type":"type","title":"Expo.PO.SyntaxError.t/0","doc":"","ref":"Expo.PO.SyntaxError.html#t:t/0"},{"type":"exception","title":"Expo.PluralForms.SyntaxError","doc":"An error raised when the syntax in a plural forms string is invalid.","ref":"Expo.PluralForms.SyntaxError.html"},{"type":"type","title":"Expo.PluralForms.SyntaxError.t/0","doc":"","ref":"Expo.PluralForms.SyntaxError.html#t:t/0"},{"type":"extras","title":"Expo","doc":"# Expo\n\n[![hex.pm badge](https://img.shields.io/badge/Package%20on%20hex.pm-informational)](https://hex.pm/packages/expo)\n[![Documentation badge](https://img.shields.io/badge/Documentation-ff69b4)][docs]\n[![.github/workflows/branch_main.yml](https://github.com/elixir-gettext/expo/actions/workflows/branch_main.yml/badge.svg)](https://github.com/elixir-gettext/expo/actions/workflows/branch_main.yml)\n[![Coverage Status](https://coveralls.io/repos/github/elixir-gettext/expo/badge.svg?branch=main)](https://coveralls.io/github/elixir-gettext/expo?branch=main)\n\n> Low-level [GNU gettext][gettext] file handling (for `.po`, `.pot`, and `.mo`\n> files), including writing and parsing.\n\nSee [the documentation][docs].\n\nFor a full Gettext integration, see the [Gettext library][elixir-gettext].","ref":"readme.html"},{"type":"extras","title":"Usage - Expo","doc":"Expo can *parse* PO, POT, and MO files from [GNU gettext][gettext]:\n\n```elixir\nExpo.PO.parse_file!(\"priv/gettext/default.pot\")\n#=> %Expo.Messages{...}\n```\n\nIt can also *write* well-formed PO, POT, and MO files:\n\n```elixir\n\"priv/gettext/default.pot\"\n|> Expo.PO.parse_file!()\n|> Expo.PO.compose()\n|> then(fn content -> File.write!(\"priv/gettext/copy.pot\") end)\n```\n\nThis library can also parse [`Plural-Form`\nheaders](https://www.gnu.org/software/gettext/manual/html_node/Plural-forms.html)\nin PO or POT files, and ships with a built-in list of languages and their plural\nforms. You can find which plural form to use for a given *amount* by using\n`Expo.PluralForms.index/2`:\n\n```elixir\n{:ok, plural_form} = Expo.PluralForms.plural_form(\"de\")\n\nExpo.PluralForms.index(plural_form, 1)\n#=> 0\nExpo.PluralForms.index(plural_form, 213)\n#=> 1\n```","ref":"readme.html#usage"},{"type":"extras","title":"License - Expo","doc":"Copyright 2015 Plataformatec Copyright 2020 Dashbit 2022 JOSHMARTIN GmbH\n\n  Licensed under the Apache License, Version 2.0 (the \"License\");\n  you may not use this file except in compliance with the License.\n  You may obtain a copy of the License at:\n\n  >  \n\n  Unless required by applicable law or agreed to in writing, software\n  distributed under the License is distributed on an \"AS IS\" BASIS,\n  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n  See the License for the specific language governing permissions and\n  limitations under the License.\n\n[docs]: https://hexdocs.pm/expo\n[elixir-gettext]: https://github.com/elixir-gettext/gettext\n[gettext]: https://www.gnu.org/software/gettext/","ref":"readme.html#license"}],"content_type":"text/markdown"}